@@ -1,7 +1,7 @@
 //
 // Copyright 2015-2017 Ettus Research, A National Instruments Company
 //
-// SPDX-License-Identifier: GPL-3.0
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include "twinrx_ctrl.hpp"
@@ -48,18 +48,18 @@ public:
         //Initialize synthesizer objects
         if (rx_id == twinrx::TWINRX_REV_C_ID) {
           _lo1_iface[size_t(CH1)] = adf535x_iface::make_adf5356(
-                  boost::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, _1));
+                  std::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, std::placeholders::_1));
           _lo1_iface[size_t(CH2)] = adf535x_iface::make_adf5356(
-                  boost::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, _1));
+                  std::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, std::placeholders::_1));
 
           _lo1_iface[size_t(CH1)]->set_pfd_freq(TWINRX_REV_C_PFD_FREQ);
           _lo1_iface[size_t(CH2)]->set_pfd_freq(TWINRX_REV_C_PFD_FREQ);
 
         } else {
           _lo1_iface[size_t(CH1)] = adf535x_iface::make_adf5355(
-                  boost::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, _1));
+                  std::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, std::placeholders::_1));
           _lo1_iface[size_t(CH2)] = adf535x_iface::make_adf5355(
-                  boost::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, _1));
+                  std::bind(&twinrx_ctrl_impl::_write_lo_spi, this, dboard_iface::UNIT_TX, std::placeholders::_1));
 
           _lo1_iface[size_t(CH1)]->set_pfd_freq(TWINRX_REV_AB_PFD_FREQ);
           _lo1_iface[size_t(CH2)]->set_pfd_freq(TWINRX_REV_AB_PFD_FREQ);
@@ -97,10 +97,10 @@ public:
 
         //Initialize clocks and LO
         bool found_rate = false;
-        BOOST_FOREACH(double rate, _db_iface->get_clock_rates(dboard_iface::UNIT_TX)) {
+        for(double rate:  _db_iface->get_clock_rates(dboard_iface::UNIT_TX)) {
             found_rate |= uhd::math::frequencies_are_equal(rate, TWINRX_DESIRED_REFERENCE_FREQ);
         }
-        BOOST_FOREACH(double rate, _db_iface->get_clock_rates(dboard_iface::UNIT_RX)) {
+        for(double rate:  _db_iface->get_clock_rates(dboard_iface::UNIT_RX)) {
             found_rate |= uhd::math::frequencies_are_equal(rate, TWINRX_DESIRED_REFERENCE_FREQ);
         }
         if (not found_rate) {
@@ -514,7 +514,7 @@ private:    //Functions
 
     void _write_lo_spi(dboard_iface::unit_t unit, const std::vector<uint32_t> &regs)
     {
-        BOOST_FOREACH(uint32_t reg, regs) {
+        for(uint32_t reg:  regs) {
              spi_config_t spi_config = spi_config_t(spi_config_t::EDGE_RISE);
              spi_config.use_custom_divider = true;
              spi_config.divider = 67;
@@ -650,5 +650,5 @@ twinrx_ctrl::sptr twinrx_ctrl::make(
     twinrx_cpld_regmap::sptr cpld_regmap,
     const dboard_id_t rx_id
 ) {
-    return sptr(new twinrx_ctrl_impl(db_iface, gpio_iface, cpld_regmap, rx_id));
+    return std::make_shared<twinrx_ctrl_impl>(db_iface, gpio_iface, cpld_regmap, rx_id);
 }
